Ocyan plugin oscar_basket
=========================

Installation
------------
Add `ocyan.plugin.oscar_basket` to your projects dependencies.

Usage
-----
This plugin fixes some bugs in oscar's basket app, required until fixed upstream.

This app provides the following features:

1. Enforcing of ``OSCAR_MAX_BASKET_QUANTITY_THRESHOLD`` even when a user logs in
   and baskets are being merged.
2. The way an option is displayed can be changed by overriding the function
   ``get_class("basket.utils", "option_display_value")``
3. Cleans up product description in the basket by not showing all these options
   rendered comma separated.
4. implemented ``DataPriceWidgetMixin`` which allows passing price data to
   form widgets, this enables updating the price with javascript when a child
   product is selected from the dropdown.
